@@ -36,34 +36,93 @@ queries_grp.add_command(generate_affects_for_component_process)
 
 
 @queries_grp.command(
+    name="product-summary",
+    help="Get Product summary.",
+)
+@click.argument("product_stream_name", required=False)
+@click.option(
+    "--ofuri",
+    "ofuri",
+    type=click.STRING,
+    shell_complete=get_product_stream_ofuris,
+    help="UNDER DEVELOPMENT",
+)
+@click.option(
+    "-s",
+    "strict_name_search",
+    is_flag=True,
+    default=False,
+    help="Strict search, exact match of component name.",
+)
+@click.pass_context
+@progress_bar
+def get_product_query(ctx, product_stream_name, ofuri, strict_name_search):
+    """get product stream."""
+    if not product_stream_name and not ofuri:
+        click.echo(ctx.get_help())
+        exit(0)
+    q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
+    cprint(q, ctx=ctx)
+
+
+@queries_grp.command(
     name="products-contain-component",
-    help="List Products containing Component.",
+    help="List Products containing (latest) Component.",
+)
+@click.argument("component_name", required=False)
+@click.option(
+    "--purl", help="Component purl, needs to be in quotes (ex. 'pkg:rpm/python-pyjwt@1.7.1')"
 )
-@click.option("--re-name", "component_re_name", help="Search name by regex.")
-@click.option("--name", "component_name")
-@click.option("--purl")
 @click.option(
     "--arch",
     default="src",
     type=click.Choice(CorgiService.get_component_arches()),
-    help="Default arch=src.",
 )
 @click.option(
     "--namespace", default=None, type=click.Choice(CorgiService.get_component_namespaces())
 )
 @click.option("--type", "component_type", type=click.Choice(CorgiService.get_component_types()))
+@click.option(
+    "-s",
+    "strict_name_search",
+    is_flag=True,
+    default=False,
+    help="Strict search, exact match of component name.",
+)
+@click.option(
+    "--affect",
+    "affect_mode",
+    is_flag=True,
+    default=False,
+    help="(Under development) Generate Affects.",
+)
+@click.option(
+    "--search-deps",
+    "search_deps",
+    is_flag=True,
+    default=False,
+    help="(Under development) Search Component dependencies.",
+)
 @click.pass_context
 @progress_bar
 def get_product_contain_component(
-    ctx, component_re_name, component_name, purl, arch, namespace, component_type
+    ctx,
+    component_name,
+    purl,
+    arch,
+    namespace,
+    component_type,
+    strict_name_search,
+    affect_mode,
+    search_deps,
 ):
-    """List components of a product version."""
-    if not purl and not component_name and not component_re_name:
+    """List products of a latest component."""
+    if not purl and not component_name:
         click.echo(ctx.get_help())
         click.echo("")
         click.echo("Must supply --name or --purl.")
         exit(0)
-    if component_name or component_re_name:
+    if component_name:
         q = query_service.invoke(core_queries.products_containing_component_query, ctx.params)
         cprint(q, ctx=ctx)
     if purl:
@@ -77,21 +136,41 @@ def get_product_contain_component(
     name="components-contain-component",
     help="List Components contain component.",
 )
-@click.option("--re-name", "component_re_name", help="Search name by regex.")
-@click.option("--name", "component_name")
+@click.argument("component_name", required=False)
 @click.option("--purl")
 @click.option("--type", "component_type", type=click.Choice(CorgiService.get_component_types()))
+@click.option("--version", "component_version")
+@click.option(
+    "--arch",
+    "component_arch",
+    type=click.Choice(CorgiService.get_component_arches()),
+    help="Default arch=src.",
+)
 @click.option("--namespace", type=click.Choice(CorgiService.get_component_namespaces()))
+@click.option(
+    "-s",
+    "strict_name_search",
+    is_flag=True,
+    default=False,
+    help="Strict search, exact match of component name.",
+)
 @click.pass_context
 @progress_bar
 def get_component_contain_component(
-    ctx, component_re_name, component_name, purl, component_type, namespace
+    ctx,
+    component_name,
+    purl,
+    component_type,
+    component_version,
+    component_arch,
+    namespace,
+    strict_name_search,
 ):
     """List components that contain component."""
-    if not purl and not component_name and not component_re_name:
+    if not component_name and not purl:
         click.echo(ctx.get_help())
         exit(0)
-    if component_name or component_re_name:
+    if component_name:
         q = query_service.invoke(core_queries.components_containing_component_query, ctx.params)
         cprint(
             q,
@@ -107,48 +186,14 @@ def get_component_contain_component(
         )
 
 
-@queries_grp.command(
-    name="product-summary",
-    help="Get Product summary.",
-)
-@click.option("--inactive", is_flag=True, default=False, help="Show inactive project streams")
-@click.option(
-    "--ofuri",
-    "ofuri",
-    type=click.STRING,
-    shell_complete=get_product_stream_ofuris,
-    help="UNDER DEVELOPMENT",
-)
-@click.option(
-    "--re-name",
-    "product_stream_re_name",
-    type=click.STRING,
-    shell_complete=get_product_stream_names,
-)
-@click.option(
-    "--name", "product_stream_name", type=click.STRING, shell_complete=get_product_stream_names
-)
-@click.pass_context
-@progress_bar
-def get_product_query(ctx, inactive, ofuri, product_stream_re_name, product_stream_name):
-    """get product stream."""
-    if not product_stream_name and not ofuri or not product_stream_re_name:
-        click.echo(ctx.get_help())
-        exit(0)
-    q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
-    cprint(q, ctx=ctx)
-
-
 @queries_grp.command(
     name="product-manifest",
     help="Get Product manifest.",
 )
+@click.argument("product_stream_name", required=False, shell_complete=get_product_stream_names)
 @click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
-@click.option(
-    "--name", "product_stream_name", type=click.STRING, shell_complete=get_product_stream_names
-)
 @click.pass_context
-def get_product_manifest_query(ctx, ofuri, product_stream_name):
+def get_product_manifest_query(ctx, product_stream_name, ofuri):
     """List components of a specific product version."""
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
@@ -165,12 +210,10 @@ def get_product_manifest_query(ctx, ofuri, product_stream_name):
     name="product-components",
     help="List LATEST Components of Product.",
 )
-@click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
-@click.option(
-    "--name", "product_stream_name", type=click.STRING, shell_complete=get_product_stream_names
-)
 @click.pass_context
-def get_product_latest_components_query(ctx, ofuri, product_stream_name):
+@click.argument("product_stream_name", required=False, shell_complete=get_product_stream_names)
+@click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
+def get_product_latest_components_query(ctx, product_stream_name, ofuri):
     """List components of a specific product version."""
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
@@ -181,7 +224,7 @@ def get_product_latest_components_query(ctx, ofuri, product_stream_name):
     if product_stream_name:
         # lookup ofuri
         q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
-        ofuri = q["ofuri"]
+        ofuri = q[0]["ofuri"]
         cond["ofuri"] = ofuri
     ctx.invoke(list_components, **cond)
 
@@ -190,12 +233,10 @@ def get_product_latest_components_query(ctx, ofuri, product_stream_name):
     name="product-all-components",
     help="List ALL Components of Product.",
 )
-@click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
-@click.option(
-    "--name", "product_stream_name", type=click.STRING, shell_complete=get_product_stream_names
-)
+@click.argument("product_stream_name", required=False, shell_complete=get_product_stream_names)
 @click.pass_context
-def get_product_all_components_query(ctx, ofuri, product_stream_name):
+@click.option("--ofuri", "ofuri", type=click.STRING, shell_complete=get_product_stream_ofuris)
+def get_product_all_components_query(ctx, product_stream_name, ofuri):
     """List components of a specific product stream."""
     if not ofuri and not product_stream_name:
         click.echo(ctx.get_help())
@@ -206,7 +247,7 @@ def get_product_all_components_query(ctx, ofuri, product_stream_name):
     if product_stream_name:
         # lookup ofuri
         q = query_service.invoke(core_queries.product_stream_summary, ctx.params)
-        ofuri = q["ofuri"]
+        ofuri = q[0]["ofuri"]
         cond["product_stream_ofuri"] = ofuri
     ctx.invoke(list_components, **cond)
 
@@ -215,9 +256,9 @@ def get_product_all_components_query(ctx, ofuri, product_stream_name):
     name="component-manifest",
     help="Get Component manifest.",
 )
+@click.pass_context
 @click.option("--uuid", "component_uuid")
 @click.option("--purl", help="Purl are URI and must be quoted.")
-@click.pass_context
 def retrieve_component_manifest(ctx, component_uuid, purl):
     """Retrieve component manifest."""
     if not component_uuid and not purl:
