@@ -6,11 +6,74 @@ import concurrent
 import logging
 from typing import Any, Dict, List
 
+import requests
+
 from griffon import CORGI_API_URL, OSIDB_API_URL, CorgiService, OSIDBService
 
 logger = logging.getLogger("rich")
 
 
+class product_stream_summary:
+    """retrieve product_stream summary"""
+
+    name = "product_stream_summary"
+    description = "retrieve product_stream summary"
+    allowed_params = ["strict_name_search", "product_stream_name", "ofuri"]
+
+    def __init__(self, params: dict) -> None:
+        self.corgi_session = CorgiService.create_session()
+        self.params = params
+        self.product_stream_name = self.params.get("product_stream_name")
+        self.ofuri = self.params.get("ofuri")
+        self.strict_name_search = self.params.get("strict_name_search", None)
+
+    def execute(self) -> List[Dict[str, Any]]:
+        cond = {}
+
+        if self.ofuri:
+            cond["ofuri"] = self.ofuri
+        elif not self.strict_name_search:
+            cond["re_name"] = self.product_stream_name
+        else:
+            cond["name"] = self.product_stream_name
+
+        # TODO - corgi bindings need to support ofuri in product_streams
+        product_streams = self.corgi_session.product_streams.retrieve_list(
+            **cond,
+            limit=400,
+            include_fields="link,ofuri,name,products,product_versions,brew_tags,manifest",
+        )
+        results = []
+        if product_streams.results:
+            for ps in product_streams.results:
+                result = {
+                    "link": ps.link,
+                    "ofuri": ps.ofuri,
+                    "name": ps.name,
+                    "product": ps.products[0]["name"],
+                    "product_version": ps.product_versions[0]["name"],
+                    "brew_tags": [brew_tag for brew_tag in ps.brew_tags.to_dict().keys()],
+                    "build_count": ps.build_count,
+                    "manifest_link": ps.manifest,
+                    "latest_components_link": ps.components,
+                    "all_components_link": f"{CORGI_API_URL}/api/v1/components?product_streams={ps.ofuri}&include_fields=link,name,purl",  # noqa
+                }
+                results.append(result)
+        else:
+            result = {
+                "link": product_streams["link"],
+                "ofuri": product_streams["ofuri"],
+                "name": product_streams["name"],
+                "product": product_streams["products"][0]["name"],
+                "product_version": product_streams["product_versions"][0]["name"],
+                "brew_tags": "",
+                "manifest_link": product_streams["manifest"],
+                "all_components_link": f"{CORGI_API_URL}/api/v1/components?product_streams={product_streams['ofuri']}&include_fields=link,name,purl",  # noqa
+            }
+            results.append(result)
+        return results
+
+
 class products_versions_affected_by_specific_cve_query:
     """Given a specific CVE ID, what products are affected?"""
 
@@ -57,22 +120,24 @@ class products_containing_specific_component_query:
     name = "products_containing_specific_component_query"
     description = "What products contain a specific component?"
     allowed_params = [
-        "component_re_name",
         "component_name",
         "purl",
         "arch",
         "namespace",
         "component_type",
+        "strict_name_search",
+        "affect_mode",
+        "search_deps",
     ]
 
     def __init__(self, params: dict) -> None:
         self.corgi_session = CorgiService.create_session()
         self.params = params
+        self.purl = self.params.get("purl")
 
     def execute(self) -> dict:
-        purl = self.params["purl"]
         c = self.corgi_session.components.retrieve_list(
-            purl=purl,
+            purl=self.purl,
         )
         return c["product_streams"]
 
@@ -83,116 +148,35 @@ class products_containing_component_query:
     name = "products_containing_component_query"
     description = "What products contain a component?"
     allowed_params = [
-        "component_re_name",
         "component_name",
         "purl",
         "arch",
         "namespace",
         "component_type",
+        "strict_name_search",
+        "affect_mode",
+        "search_deps",
     ]
 
     def __init__(self, params: dict) -> None:
         self.corgi_session = CorgiService.create_session()
         self.params = params
+        self.component_name = self.params.get("component_name")
+        self.component_type = self.params.get("component_type")
+        self.strict_name_search = self.params.get("strict_name_search")
+        self.search_deps = self.params.get("search_deps")
+        self.ns = self.params.get("namespace")
 
     def execute(self) -> List[Dict[str, Any]]:
-        component_name = self.params["component_name"]
-        component_re_name = self.params["component_re_name"]
-        component_type = self.params["component_type"]
-        ns = self.params["namespace"]
-        cond = {}
-        if component_re_name:
-            cond["re_name"] = component_re_name
+        params = {"view": "latest"}
+        if not self.strict_name_search:
+            params["re_name"] = self.component_name  # type: ignore
         else:
-            cond["name"] = component_name
-        if component_type:
-            cond["type"] = component_type
-        if ns == "REDHAT":
-            cond["namespace"] = "REDHAT"
-
-        components: List[Any] = []
-        logger.debug("starting parallel http requests")
-        component_cnt = self.corgi_session.components.retrieve_list(**cond).count
-        if component_cnt < 3000000:
-            with concurrent.futures.ThreadPoolExecutor() as executor:
-                futures = []
-                components = list()
-                for batch in range(0, component_cnt, 30):
-                    futures.append(
-                        executor.submit(
-                            self.corgi_session.components.retrieve_list,
-                            **cond,
-                            offset=batch,
-                            include_fields="uuid,name,namespace,purl,nvr,related_url,software_build,product_streams,sources",  # noqa
-                            limit=30,
-                        )
-                    )
-                for future in concurrent.futures.as_completed(futures):
-                    try:
-                        components.extend(future.result().results)
-                    except Exception as exc:
-                        logger.warning("%r generated an exception: %s" % (future, exc))
-
-        results = []
-        for component in components:
-            logger.debug(component.sources)
-            sources = []
-            for source in component.sources:
-                if "arch=src" in source["purl"]:
-                    sources.append(source["purl"])
-            for ps in component.product_streams:
-                result = {
-                    "link": ps["link"],
-                    "ofuri": ps["ofuri"],
-                    "name": ps["name"],
-                    "component_purl": component.purl,
-                    "component_name": component.name,
-                    "component_related_url": component.related_url,
-                    "component_software_build": component.software_build.to_dict(),
-                    "component_root_components": sources,
-                }
-                results.append(result)
-        return results
-
-
-class product_stream_summary:
-    """retrieve product_stream summary"""
-
-    name = "product_stream_summary"
-    description = "retrieve product_stream summary"
-    allowed_params = ["product_stream_re_name", "product_stream_name", "ofuri", "inactive"]
-
-    def __init__(self, params: dict) -> None:
-        self.corgi_session = CorgiService.create_session()
-        self.params = params
-
-    def execute(self) -> dict:
-        cond = {}
-        product_stream_name = self.params["product_stream_name"]
-        ofuri = self.params["ofuri"]
-        if product_stream_name:
-            cond["name"] = product_stream_name
-        if ofuri:
-            cond["ofuri"] = ofuri
-        # TODO - corgi bindings need to support ofuri in product_streams
-        product_stream = self.corgi_session.product_streams.retrieve_list(**cond)
-        components_cnt = self.corgi_session.components.retrieve_list(
-            ofuri=product_stream["ofuri"], view="summary", limit=1
-        ).count
-        return {
-            "link": product_stream["link"],
-            "ofuri": product_stream["ofuri"],
-            "name": product_stream["name"],
-            "product": product_stream["products"][0]["name"],
-            "product_version": product_stream["product_versions"][0]["name"],
-            "brew_tags": list(product_stream["brew_tags"].keys()),
-            "build_count": product_stream["build_count"],
-            "latest_component_count": components_cnt,
-            "manifest_link": product_stream["manifest"],
-            "shipped_components_link": "tbd",
-            "latest_components_link": product_stream["components"],
-            "all_components_link": f"{CORGI_API_URL}/api/v1/components?product_streams={product_stream['ofuri']}&include_fields=link,name,purl",  # noqa
-        }
+            params["name"] = self.component_name  # type: ignore
+        # TODO - not yet exposed in bindings
+        response = requests.get(f"{CORGI_API_URL}/api/v1/components", params=params)
+        latest_src_results = response.json()["results"]
+        return latest_src_results
 
 
 class components_containing_specific_component_query:
@@ -200,17 +184,26 @@ class components_containing_specific_component_query:
 
     name = "components_containing_specific_component_query"
     description = "What components contain a specific component?"
-    allowed_params = ["component_re_name", "component_name", "purl", "component_type", "namespace"]
+    allowed_params = [
+        "component_re_name",
+        "component_name",
+        "purl",
+        "component_type",
+        "component_version",
+        "component_arch",
+        "namespace",
+        "strict_name_search",
+    ]
 
     def __init__(self, params: dict):
         self.corgi_session = CorgiService.create_session()
         self.params = params
+        self.purl = self.params.get("purl")
 
     def execute(self) -> dict:
-        purl = self.params["purl"]
-        if purl:
+        if self.purl:
             c = self.corgi_session.components.retrieve_list(
-                purl=purl,
+                purl=self.purl,
             )
             component_type = self.params["component_type"]
             sources = c["sources"]
@@ -218,8 +211,9 @@ class components_containing_specific_component_query:
                 sources = [source for source in sources if component_type.lower() in source["purl"]]
         return {
             "link": c["link"],
-            "type": component_type,
+            "type": c["type"],
             "name": c["name"],
+            "version": c["version"],
             "purl": c["purl"],
             "sources": sources,
         }
@@ -230,26 +224,38 @@ class components_containing_component_query:
 
     name = "components_containing_component_query"
     description = "What components contain a component?"
-    allowed_params = ["component_re_name", "component_name", "purl", "component_type", "namespace"]
+    allowed_params = [
+        "component_name",
+        "purl",
+        "component_type",
+        "component_version",
+        "component_arch",
+        "namespace",
+        "strict_name_search",
+    ]
 
     def __init__(self, params: dict) -> None:
         self.corgi_session = CorgiService.create_session()
         self.params = params
+        self.component_name = self.params.get("component_name")
+        self.component_type = self.params.get("component_type")
+        self.component_version = self.params.get("component_version")
+        self.component_arch = self.params.get("component_arch")
+        self.namespace = self.params.get("namespace")
+        self.strict_name_search = self.params.get("strict_name_search")
 
     def execute(self) -> List[Dict[str, Any]]:
-        component_type = self.params["component_type"]
-        component_name = self.params["component_name"]
-        component_re_name = self.params["component_re_name"]
-        namespace = self.params["namespace"]
-
         cond = {}
-        if component_re_name:
-            cond["re_name"] = component_re_name
+        if not self.strict_name_search:
+            cond["re_name"] = self.component_name
         else:
-            cond["name"] = component_name
-
-        if namespace:
-            cond["namespace"] = namespace
+            cond["name"] = self.component_name
+        if self.component_version:
+            cond["version"] = self.component_version
+        if self.component_arch:
+            cond["arch"] = self.component_arch
+        if self.namespace:
+            cond["namespace"] = self.namespace
 
         components: List[Any] = []
         logger.debug("starting parallel http requests")
@@ -258,14 +264,14 @@ class components_containing_component_query:
             with concurrent.futures.ThreadPoolExecutor() as executor:
                 futures = []
                 components = list()
-                for batch in range(0, component_cnt, 30):
+                for batch in range(0, component_cnt, 120):
                     futures.append(
                         executor.submit(
                             self.corgi_session.components.retrieve_list,
                             **cond,
                             offset=batch,
-                            include_fields="link,name,purl,sources",
-                            limit=30,  # noqa
+                            include_fields="link,name,type,version,purl,sources",
+                            limit=120,  # noqa
                         )
                     )
                 for future in concurrent.futures.as_completed(futures):
@@ -276,15 +282,17 @@ class components_containing_component_query:
 
         results = []
         for c in components:
-            sources = []
-            for source in c.sources:
-                sources.append({"link": source["link"], "purl": source["purl"]})
-            if component_type:
-                sources = [source for source in sources if component_type.lower() in source["purl"]]
+            sources = [{"link": source["link"], "purl": source["purl"]} for source in c.sources]
+            if self.component_type:
+                sources = [
+                    source for source in sources if self.component_type.lower() in source["purl"]
+                ]
             results.append(
                 {
                     "link": c.link,
+                    "type": c.type,
                     "name": c.name,
+                    "version": c.version,
                     "purl": c.purl,
                     "sources": sources,
                 }
@@ -310,19 +318,19 @@ class components_affected_by_specific_cve_query:
         self.corgi_session = CorgiService.create_session()
         self.osidb_session = OSIDBService.create_session()
         self.params = params
+        self.cve_id = self.params.get("cve_id")
+        self.affectedness = self.params.get("affectedness")
+        self.affect_resolution = self.params.get("affect_resolution")
+        self.affect_impact = self.params.get("affect_impact")
 
     def execute(self) -> dict:
-        cve_id = self.params["cve_id"]
-        affectedness = self.params["affectedness"]
-        affect_resolution = self.params["affect_resolution"]
-        affect_impact = self.params["affect_impact"]
         cond = {}
-        if affectedness:
-            cond["affectedness"] = affectedness
-        if affect_resolution:
-            cond["resolution"] = affect_resolution
-        if affect_impact:
-            cond["impact"] = affect_impact
+        if self.affectedness:
+            cond["affectedness"] = self.affectedness
+        if self.affect_resolution:
+            cond["resolution"] = self.affect_resolution
+        if self.affect_impact:
+            cond["impact"] = self.affect_impact
         component_type = self.params["component_type"]
         namespace = self.params["namespace"]
         component_cond = {}
@@ -330,7 +338,7 @@ class components_affected_by_specific_cve_query:
             component_cond["namespace"] = namespace
         if component_type:
             component_cond["type"] = component_type
-        flaw = self.osidb_session.flaws.retrieve(cve_id)
+        flaw = self.osidb_session.flaws.retrieve(self.cve_id)
         affects = self.osidb_session.affects.retrieve_list(
             flaw=flaw.uuid, **cond, limit=1000
         ).results
